mask

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package mask provides secret value masking.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsSensitiveKey

func IsSensitiveKey(key string) bool

IsSensitiveKey returns true if the key name suggests a secret value.

func Redact

func Redact(value string) string

Redact masks a value unconditionally.

func Value

func Value(key, value string) string

Value masks a value if the key is sensitive. Shows last 4 chars for values longer than 8 chars, otherwise "****".

Types

This section is empty.

Jump to