suggest

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package suggest provides typo correction suggestions.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Closest

func Closest(input string, candidates []string, maxDistance int) string

Closest returns the closest match from candidates using Levenshtein distance. Returns empty string if no candidate is within maxDistance or candidates is empty.

Types

This section is empty.

Jump to