Documentation
¶
Overview ¶
Package service manages microCMS service definitions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Service ¶
type Service struct {
ServiceID string `json:"serviceId"`
Alias string `json:"alias,omitempty"`
ContentAPIBaseURL string `json:"contentApiBaseUrl"`
ManagementAPIBaseURL string `json:"managementApiBaseUrl"`
ContentAPIKey string `json:"contentApiKey"`
ManagementAPIKey string `json:"managementApiKey,omitempty"`
CreatedAt time.Time `json:"createdAt"`
UpdatedAt time.Time `json:"updatedAt"`
}
Service represents a registered microCMS service.
func (*Service) ContentBaseURL ¶
ContentBaseURL returns the content API base URL for this service.
func (*Service) ManagementBaseURL ¶
ManagementBaseURL returns the management API base URL for this service.
type Store ¶
type Store struct {
// contains filtered or unexported fields
}
Store provides CRUD operations for service definitions.
func NewStore ¶
func NewStore() *Store
NewStore creates a store using the default service directory.
func NewStoreWithDir ¶
NewStoreWithDir creates a store using a custom directory (for testing).
func (*Store) GetDecrypted ¶
GetDecrypted retrieves a service with decrypted API keys.
Click to show internal directories.
Click to hide internal directories.